

set -ex



python -m pip check
jupyter notebook -h
jupyter-notebook -h
jupyter labextension list
jupyter labextension list 1>labextensions 2>&1
cat labextensions | rg "@jupyter-notebook/lab-extension.*OK"
exit 0
